<?php
class Budget {
    private $conn;
    private $table_name = "budgets";

    public $id;
    public $company_id;
    public $quarter;
    public $year;
    public $sales;
    public $other_income;
    public $cost_of_sales;
    public $admin_expenses;
    public $other_expenses;
    public $zakat;
    public $net_income;
    public $status;

    public function __construct($db) {
        $this->conn = $db;
    }

    public function create() {
        $query = "INSERT INTO " . $this->table_name . "
                (company_id, quarter, year, sales, other_income, cost_of_sales, 
                admin_expenses, other_expenses, zakat, net_income, status)
                VALUES
                (:company_id, :quarter, :year, :sales, :other_income, :cost_of_sales,
                :admin_expenses, :other_expenses, :zakat, :net_income, :status)";

        $stmt = $this->conn->prepare($query);

        $this->calculateNetIncome();
        
        return $stmt->execute([
            ":company_id" => $this->company_id,
            ":quarter" => $this->quarter,
            ":year" => $this->year,
            ":sales" => $this->sales,
            ":other_income" => $this->other_income,
            ":cost_of_sales" => $this->cost_of_sales,
            ":admin_expenses" => $this->admin_expenses,
            ":other_expenses" => $this->other_expenses,
            ":zakat" => $this->zakat,
            ":net_income" => $this->net_income,
            ":status" => $this->status
        ]);
    }

    private function calculateNetIncome() {
        $total_income = $this->sales + $this->other_income;
        $total_expenses = $this->cost_of_sales + $this->admin_expenses + $this->other_expenses;
        $this->net_income = $total_income - $total_expenses;
        $this->zakat = max(0, $this->net_income * 0.025);
    }

    public function read() {
        $query = "SELECT b.*, c.name as company_name 
                 FROM " . $this->table_name . " b
                 LEFT JOIN companies c ON b.company_id = c.id
                 ORDER BY b.created_at DESC";

        $stmt = $this->conn->prepare($query);
        $stmt->execute();
        return $stmt;
    }

    public function readOne() {
        $query = "SELECT b.*, c.name as company_name 
                 FROM " . $this->table_name . " b
                 LEFT JOIN companies c ON b.company_id = c.id
                 WHERE b.id = ?";

        $stmt = $this->conn->prepare($query);
        $stmt->execute([$this->id]);
        return $stmt;
    }

    public function update() {
        $query = "UPDATE " . $this->table_name . "
                SET sales = :sales,
                    other_income = :other_income,
                    cost_of_sales = :cost_of_sales,
                    admin_expenses = :admin_expenses,
                    other_expenses = :other_expenses,
                    status = :status
                WHERE id = :id";

        $stmt = $this->conn->prepare($query);
        
        $this->calculateNetIncome();

        return $stmt->execute([
            ":sales" => $this->sales,
            ":other_income" => $this->other_income,
            ":cost_of_sales" => $this->cost_of_sales,
            ":admin_expenses" => $this->admin_expenses,
            ":other_expenses" => $this->other_expenses,
            ":status" => $this->status,
            ":id" => $this->id
        ]);
    }
}
?>