<?php
class Company {
    private $conn;
    private $table_name = "companies";

    public $id;
    public $name;
    public $commercial_register;
    public $vat_number;
    public $address;
    public $created_at;

    public function __construct($db) {
        $this->conn = $db;
    }

    // إنشاء شركة جديدة
    public function create() {
        $query = "INSERT INTO " . $this->table_name . " (name, commercial_register, vat_number, address) VALUES (:name, :commercial_register, :vat_number, :address)";
        
        $stmt = $this->conn->prepare($query);

        // تنظيف البيانات
        $this->name = htmlspecialchars(strip_tags($this->name));
        $this->commercial_register = htmlspecialchars(strip_tags($this->commercial_register));
        $this->vat_number = htmlspecialchars(strip_tags($this->vat_number));
        $this->address = htmlspecialchars(strip_tags($this->address));

        // ربط القيم
        $stmt->bindParam(':name', $this->name);
        $stmt->bindParam(':commercial_register', $this->commercial_register);
        $stmt->bindParam(':vat_number', $this->vat_number);
        $stmt->bindParam(':address', $this->address);

        // تنفيذ العملية
        if ($stmt->execute()) {
            return true;
        }
        return false;
    }

    // قراءة جميع الشركات
    public function read() {
        $query = "SELECT * FROM " . $this->table_name . " ORDER BY created_at DESC";

        $stmt = $this->conn->prepare($query);
        $stmt->execute();
        
        return $stmt;
    }

    // تحديث شركة
    public function update() {
        $query = "UPDATE " . $this->table_name . " SET name = :name, commercial_register = :commercial_register, vat_number = :vat_number, address = :address WHERE id = :id";

        $stmt = $this->conn->prepare($query);

        // تنظيف البيانات
        $this->name = htmlspecialchars(strip_tags($this->name));
        $this->commercial_register = htmlspecialchars(strip_tags($this->commercial_register));
        $this->vat_number = htmlspecialchars(strip_tags($this->vat_number));
        $this->address = htmlspecialchars(strip_tags($this->address));
        $this->id = htmlspecialchars(strip_tags($this->id));

        // ربط القيم
        $stmt->bindParam(':name', $this->name);
        $stmt->bindParam(':commercial_register', $this->commercial_register);
        $stmt->bindParam(':vat_number', $this->vat_number);
        $stmt->bindParam(':address', $this->address);
        $stmt->bindParam(':id', $this->id);

        // تنفيذ العملية
        if ($stmt->execute()) {
            return true;
        }
        return false;
    }

    // حذف شركة
    public function delete() {
        $query = "DELETE FROM " . $this->table_name . " WHERE id = :id";

        $stmt = $this->conn->prepare($query);

        // تنظيف البيانات
        $this->id = htmlspecialchars(strip_tags($this->id));

        // ربط القيمة
        $stmt->bindParam(':id', $this->id);

        // تنفيذ العملية
        if ($stmt->execute()) {
            return true;
        }
        return false;
    }
}
?>